@@ -1,6 +1,6 @@
 package Org::Element::Base;
 BEGIN {
-  $Org::Element::Base::VERSION = '0.06';
+  $Org::Element::Base::VERSION = '0.07';
 }
 # ABSTRACT: Base class for element of Org document
 
@@ -110,6 +110,52 @@ sub walk {
     }
 }
 
+
+sub find {
+    my ($self, $criteria) = @_;
+    return unless $self->children;
+    my @res;
+    $self->walk(
+        sub {
+            my $el = shift;
+            if (ref($criteria) eq 'CODE') {
+                push @res, $el if $criteria->($el);
+            } elsif ($criteria =~ /^\w+$/) {
+                push @res, $el if $el->isa("Org::Element::$criteria");
+            } else {
+                push @res, $el if $el->isa($criteria);
+            }
+        });
+    @res;
+}
+
+
+sub walk_parents {
+    my ($self, $code) = @_;
+    my $parent = $self->parent;
+    while ($parent) {
+        return $parent unless $code->($self, $parent);
+        $parent = $parent->parent;
+    }
+    return;
+}
+
+
+sub headline {
+    my ($self) = @_;
+    my $h;
+    $self->walk_parents(
+        sub {
+            my ($el, $p) = @_;
+            if ($p->isa('Org::Element::Headline')) {
+                $h = $p;
+                return;
+            }
+            1;
+        });
+    $h;
+}
+
 1;
 
 __END__
@@ -121,7 +167,7 @@ Org::Element::Base - Base class for element of Org document
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 ATTRIBUTES
 
@@ -171,6 +217,22 @@ property is not found in nearest properties drawer.
 
 Call CODEREF for node and all descendent nodes, depth-first.
 
+=head2 find(CRITERIA) -> ELEMENTS
+
+Find subelements. CRITERIA can be a word (e.g. 'Headline' meaning of class
+'Org::Element::Headline') or a class name ('Org::Element::ListItem') or a
+coderef (which will be given the element to test). Will return matched elements.
+
+=head2 $el->walk_parents(CODE)
+
+Run CODEREF for parent, and its parent, and so on until the root element (the
+document), or until CODEREF returns a false value. CODEREF will be supplied
+($el, $parent). Will return the last parent walked.
+
+=head2 $el->headline()
+
+Get current headline.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
